#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
tip: pyuic5 -x ventana.ui -o ventana_ui.py
@author: martindrech

This is a fast solution, for controlling and performing measurements with the rigol function generator. 

"""

from PyQt5 import QtCore, QtWidgets, QtGui
from PyQt5.QtCore import QSettings
from PyQt5.QtWidgets import QAction, QFileDialog, QInputDialog, QWidget
from resources.rigol_measurement_ui import Ui_Frame

from appsettings import WORKING_DIR

class RigolMeasurementFrame(QtWidgets.QFrame, Ui_Frame):
    
    
    def __init__(self):
        super().__init__()
        self.setupUi(self)

        self.treeModel = QtGui.QStandardItemModel()
        self.treeView.setAlternatingRowColors(True)
        self.treeView.setSortingEnabled(True)
        self.treeView.setHeaderHidden(False)
        self.treeView.setSelectionBehavior(QtGui.QAbstractItemView.SelectItems)
        self.treeView.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.treeModel.setHorizontalHeaderLabels(['Parameter', 'Value'])
        self.treeView.setModel(self.treeModel)


        self.treeModel.insertRow(0)            
        self.treeModel.setData(self.treeModel.index(0, 0), r'df (kHz)')
        self.treeModel.setData(self.treeModel.index(0, 1), '?')
    
        self.saveMeasureButton.setEnabled(False)

        self.configure_spinBoxes()

    def select_folder(self):
        directory = QFileDialog.getExistingDirectory(self, 'Choose directory')
    

    def configure_spinBoxes(self):
        self.startValue.setMinimum(0)
        self.startValue.setMaximum(10e6)
        self.startValue.setSingleStep(1000)
        self.startValue.setOpts(suffix='Hz', siPrefix=True)

        self.endValue.setMinimum(0)
        self.endValue.setMaximum(10e6)
        self.endValue.setSingleStep(1000)
        self.endValue.setOpts(suffix='Hz', siPrefix=True)

        self.stepsNum.setMaximum(1000000)
        


    def update_tree(self):
        try:
            self.treeModel.setData(self.treeModel.index(0, 1), (self.endValue.value()-self.startValue.value())/(self.stepsNum.value()-1)/1000 )
        except:
            self.treeModel.setData(self.treeModel.index(0, 1), '?')
